@@ -117,12 +117,12 @@ is_image (const char *url)
 static TotemPlParserResult
 parse_rss_item (TotemPlParser *parser, xml_node_t *parent)
 {
-	const char *title, *uri, *description, *author;
+	const char *title, *uri, *description, *author, *img;
 	const char *pub_date, *duration, *filesize, *content_type, *id;
 	xml_node_t *node;
 
 	title = uri = description = author = content_type = NULL;
-	pub_date = duration = filesize = id = NULL;
+	img = pub_date = duration = filesize = id = NULL;
 
 	for (node = parent->child; node != NULL; node = node->next) {
 		if (node->name == NULL)
@@ -151,8 +151,11 @@ parse_rss_item (TotemPlParser *parser, xml_node_t *parent)
 
 			tmp = xml_parser_get_property (node, "type");
 			if (tmp != NULL &&
-			    g_str_has_prefix (tmp, "audio/") == FALSE)
+			    g_str_has_prefix (tmp, "audio/") == FALSE) {
+				if (g_str_has_prefix (tmp, "image/"))
+					img = xml_parser_get_property (node, "url");
 				continue;
+			}
 			content_type = tmp;
 
 			tmp = xml_parser_get_property (node, "url");
@@ -201,6 +204,7 @@ parse_rss_item (TotemPlParser *parser, xml_node_t *parent)
 					 TOTEM_PL_PARSER_FIELD_DURATION, duration,
 					 TOTEM_PL_PARSER_FIELD_FILESIZE, filesize,
 					 TOTEM_PL_PARSER_FIELD_CONTENT_TYPE, content_type,
+					 TOTEM_PL_PARSER_FIELD_IMAGE_URI, img,
 					 NULL);
 	}
 
@@ -693,7 +697,7 @@ totem_pl_parser_get_feed_uri (char *data, gsize len, gboolean debug)
 {
 	xml_node_t* doc;
 	const char *uri;
-	GFile *ret;
+	GFile *ret = NULL;
 	GByteArray *content;
 
 	uri = NULL;
@@ -716,11 +720,8 @@ totem_pl_parser_get_feed_uri (char *data, gsize len, gboolean debug)
 		return NULL;
 
 	/* If the document has no name */
-	if (doc->name == NULL
-	    || g_ascii_strcasecmp (doc->name, "plist") != 0) {
-		xml_parser_free_tree (doc);
-		return NULL;
-	}
+	if (doc->name == NULL || g_ascii_strcasecmp (doc->name, "plist") != 0)
+		goto out;
 
 	/* Redirect plist? Find a goto action */
 	uri = totem_pl_parser_parse_plist (doc);
@@ -728,15 +729,17 @@ totem_pl_parser_get_feed_uri (char *data, gsize len, gboolean debug)
 	if (debug)
 		g_print ("Found redirect URL: %s\n", uri);
 
-	if (uri == NULL) {
-		return NULL;
-	} else {
+	if (uri == NULL)
+		goto out;
 
-		content = totem_pl_parser_load_http_itunes (uri, debug);
-		ret = totem_pl_parser_get_feed_uri ((char *) content->data, content->len, debug);
-		g_byte_array_free (content, TRUE);
-	}
+	content = totem_pl_parser_load_http_itunes (uri, debug);
+	if (!content)
+		goto out;
+	ret = totem_pl_parser_get_feed_uri ((char *) content->data, content->len, debug);
+	g_byte_array_free (content, TRUE);
 
+out:
+	xml_parser_free_tree (doc);
 	return ret;
 }
 
